@@ -1,4 +1,5 @@
 from keras_cv_attention_models.halonet.halonet import (
+    halo_attention,
     HaloNet,
     HaloNetH0,
     HaloNetH1,
@@ -13,7 +14,8 @@ from keras_cv_attention_models.halonet.halonet import (
     HaloNetSE33T,
     HaloNextECA26T,
     HaloRegNetZB,
-    halo_attention,
+    HaloBotNet50T,
+    set_global_tpu_test,
 )
 
 
@@ -67,11 +69,12 @@ Model architectures:
   | HaloNetH5      | 30.7M  | 448              | 84.0     |
   | HaloNetH6      | 43.4M  | 512              | 84.4     |
   | HaloNetH7      | 67.4M  | 600              | 84.9     |
-  | HaloNextECA26T | 10.7M  | 256              | 78.84    |
+  | HaloNextECA26T | 10.7M  | 256              | 79.50    |
   | HaloNet26T     | 12.5M  | 256              | 79.13    |
   | HaloNetSE33T   | 13.7M  | 256              | 80.99    |
   | HaloRegNetZB   | 11.68M | 224              | 81.042   |
-  | HaloNet50T     | 22.7M  | 256              | 81.35    |
+  | HaloNet50T     | 22.7M  | 256              | 81.70    |
+  | HaloBotNet50T  | 22.6M  | 256              | 82.0     |
 """
 
 HaloNetH0.__doc__ = __head_doc__ + """
@@ -94,6 +97,7 @@ HaloNetSE33T.__doc__ = HaloNet26T.__doc__
 HaloNextECA26T.__doc__ = HaloNet26T.__doc__
 HaloNet50T.__doc__ = HaloNet26T.__doc__
 HaloRegNetZB.__doc__ = HaloNet26T.__doc__
+HaloBotNet50T.__doc__ = HaloNet26T.__doc__
 
 halo_attention.__doc__ = __head_doc__ + """
 Halo Attention. Defined as function, not layer.
