@@ -13,6 +13,7 @@ PRETRAINED_DICT = {
     "haloregnetz_b": {"imagenet": "e889647682d1c554de032d376acf0c48"},
     "halobotnet50t": {"imagenet": "0af1faad1a81e468d6e670e9fc253edc"},
 }
+GLOBAL_TPU_TEST = False
 
 
 def halo_attention(
@@ -353,3 +354,9 @@ def HaloBotNet50T(input_shape=(256, 256, 3), num_classes=1000, activation="swish
     model = AotNet(model_name="halobotnet50t", **locals(), **kwargs)
     reload_model_weights(model, pretrained_dict=PRETRAINED_DICT, sub_release="halonet", input_shape=input_shape, pretrained=pretrained)
     return model
+
+
+def set_global_tpu_test(tpu_test=False):
+    """ Set True for force using `Conv2D` instead of `tf.image.extract_patches`. Also works for TFLite conversion. """
+    global GLOBAL_TPU_TEST
+    GLOBAL_TPU_TEST = tpu_test
